# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    AidocExoticKeywordsResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAidocExotic:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_ask_continue(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.ask_continue()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_ask_continue_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.ask_continue(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_ask_continue(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.ask_continue()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_ask_continue(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.ask_continue() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_if_need_image(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.if_need_image()
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    def test_method_if_need_image_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.if_need_image(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    def test_raw_response_if_need_image(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.if_need_image()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    def test_streaming_response_if_need_image(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.if_need_image() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert_matches_type(object, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_keywords(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.keywords()
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    def test_method_keywords_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.keywords(
            content="content",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    def test_raw_response_keywords(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.keywords()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    def test_streaming_response_keywords(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.keywords() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_options(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.options()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_options_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.options(
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_options(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.options()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_options(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.options() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_pic_result(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.pic_result()
        assert aidoc_exotic is None

    @parametrize
    def test_method_pic_result_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    def test_raw_response_pic_result(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert aidoc_exotic is None

    @parametrize
    def test_streaming_response_pic_result(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_question(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.question()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_question_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_question(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.question()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_question(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.question() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.report(
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert aidoc_exotic is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report_task(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.report_task(
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    def test_method_report_task_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.report_task(
            session_id="session_id",
            report_type=0,
        )
        assert aidoc_exotic is None

    @parametrize
    def test_raw_response_report_task(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert aidoc_exotic is None

    @parametrize
    def test_streaming_response_report_task(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_summarize(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.summarize()
        assert aidoc_exotic is None

    @parametrize
    def test_method_summarize_with_all_params(self, client: Czlai) -> None:
        aidoc_exotic = client.aidoc_exotic.summarize(
            image_url="image_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    def test_raw_response_summarize(self, client: Czlai) -> None:
        response = client.aidoc_exotic.with_raw_response.summarize()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = response.parse()
        assert aidoc_exotic is None

    @parametrize
    def test_streaming_response_summarize(self, client: Czlai) -> None:
        with client.aidoc_exotic.with_streaming_response.summarize() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAidocExotic:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_ask_continue(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.ask_continue()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_ask_continue_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.ask_continue(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_ask_continue(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.ask_continue()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_ask_continue(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.ask_continue() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_if_need_image(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.if_need_image()
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    async def test_method_if_need_image_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.if_need_image(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    async def test_raw_response_if_need_image(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.if_need_image()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert_matches_type(object, aidoc_exotic, path=["response"])

    @parametrize
    async def test_streaming_response_if_need_image(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.if_need_image() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert_matches_type(object, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_keywords(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.keywords()
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    async def test_method_keywords_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.keywords(
            content="content",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    async def test_raw_response_keywords(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.keywords()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

    @parametrize
    async def test_streaming_response_keywords(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.keywords() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert_matches_type(AidocExoticKeywordsResponse, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_options(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.options()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_options_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.options(
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_options(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.options()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_options(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.options() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_pic_result(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.pic_result()
        assert aidoc_exotic is None

    @parametrize
    async def test_method_pic_result_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    async def test_raw_response_pic_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert aidoc_exotic is None

    @parametrize
    async def test_streaming_response_pic_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_question(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.question()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_question_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_question(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.question()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert_matches_type(str, aidoc_exotic, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_question(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.question() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert_matches_type(str, aidoc_exotic, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.report(
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert aidoc_exotic is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report_task(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.report_task(
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    async def test_method_report_task_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.report_task(
            session_id="session_id",
            report_type=0,
        )
        assert aidoc_exotic is None

    @parametrize
    async def test_raw_response_report_task(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert aidoc_exotic is None

    @parametrize
    async def test_streaming_response_report_task(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_summarize(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.summarize()
        assert aidoc_exotic is None

    @parametrize
    async def test_method_summarize_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc_exotic = await async_client.aidoc_exotic.summarize(
            image_url="image_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc_exotic is None

    @parametrize
    async def test_raw_response_summarize(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc_exotic.with_raw_response.summarize()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc_exotic = await response.parse()
        assert aidoc_exotic is None

    @parametrize
    async def test_streaming_response_summarize(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc_exotic.with_streaming_response.summarize() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc_exotic = await response.parse()
            assert aidoc_exotic is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["BuriedpointCreateParams"]


class BuriedpointCreateParams(TypedDict, total=False):
    point: Required[str]
    """参数"""

    code: str
    """微信 code"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pets import (
    PetsResource,
    AsyncPetsResource,
    PetsResourceWithRawResponse,
    AsyncPetsResourceWithRawResponse,
    PetsResourceWithStreamingResponse,
    AsyncPetsResourceWithStreamingResponse,
)
from .aidoc import (
    AidocResource,
    AsyncAidocResource,
    AidocResourceWithRawResponse,
    AsyncAidocResourceWithRawResponse,
    AidocResourceWithStreamingResponse,
    AsyncAidocResourceWithStreamingResponse,
)
from .aipic import (
    AipicResource,
    AsyncAipicResource,
    AipicResourceWithRawResponse,
    AsyncAipicResourceWithRawResponse,
    AipicResourceWithStreamingResponse,
    AsyncAipicResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .aipics import (
    AipicsResource,
    AsyncAipicsResource,
    AipicsResourceWithRawResponse,
    AsyncAipicsResourceWithRawResponse,
    AipicsResourceWithStreamingResponse,
    AsyncAipicsResourceWithStreamingResponse,
)
from .logins import (
    LoginsResource,
    AsyncLoginsResource,
    LoginsResourceWithRawResponse,
    AsyncLoginsResourceWithRawResponse,
    LoginsResourceWithStreamingResponse,
    AsyncLoginsResourceWithStreamingResponse,
)
from .upload import (
    UploadResource,
    AsyncUploadResource,
    UploadResourceWithRawResponse,
    AsyncUploadResourceWithRawResponse,
    UploadResourceWithStreamingResponse,
    AsyncUploadResourceWithStreamingResponse,
)
from .ai_conv import (
    AIConvResource,
    AsyncAIConvResource,
    AIConvResourceWithRawResponse,
    AsyncAIConvResourceWithRawResponse,
    AIConvResourceWithStreamingResponse,
    AsyncAIConvResourceWithStreamingResponse,
)
from .ai_memes import (
    AIMemesResource,
    AsyncAIMemesResource,
    AIMemesResourceWithRawResponse,
    AsyncAIMemesResourceWithRawResponse,
    AIMemesResourceWithStreamingResponse,
    AsyncAIMemesResourceWithStreamingResponse,
)
from .ai_trial import (
    AITrialResource,
    AsyncAITrialResource,
    AITrialResourceWithRawResponse,
    AsyncAITrialResourceWithRawResponse,
    AITrialResourceWithStreamingResponse,
    AsyncAITrialResourceWithStreamingResponse,
)
from .policies import (
    PoliciesResource,
    AsyncPoliciesResource,
    PoliciesResourceWithRawResponse,
    AsyncPoliciesResourceWithRawResponse,
    PoliciesResourceWithStreamingResponse,
    AsyncPoliciesResourceWithStreamingResponse,
)
from .ai_trials import (
    AITrialsResource,
    AsyncAITrialsResource,
    AITrialsResourceWithRawResponse,
    AsyncAITrialsResourceWithRawResponse,
    AITrialsResourceWithStreamingResponse,
    AsyncAITrialsResourceWithStreamingResponse,
)
from .whitelist import (
    WhitelistResource,
    AsyncWhitelistResource,
    WhitelistResourceWithRawResponse,
    AsyncWhitelistResourceWithRawResponse,
    WhitelistResourceWithStreamingResponse,
    AsyncWhitelistResourceWithStreamingResponse,
)
from .ai_checkup import (
    AICheckupResource,
    AsyncAICheckupResource,
    AICheckupResourceWithRawResponse,
    AsyncAICheckupResourceWithRawResponse,
    AICheckupResourceWithStreamingResponse,
    AsyncAICheckupResourceWithStreamingResponse,
)
from .evaluation import (
    EvaluationResource,
    AsyncEvaluationResource,
    EvaluationResourceWithRawResponse,
    AsyncEvaluationResourceWithRawResponse,
    EvaluationResourceWithStreamingResponse,
    AsyncEvaluationResourceWithStreamingResponse,
)
from .magnum_keys import (
    MagnumKeysResource,
    AsyncMagnumKeysResource,
    MagnumKeysResourceWithRawResponse,
    AsyncMagnumKeysResourceWithRawResponse,
    MagnumKeysResourceWithStreamingResponse,
    AsyncMagnumKeysResourceWithStreamingResponse,
)
from .point_tasks import (
    PointTasksResource,
    AsyncPointTasksResource,
    PointTasksResourceWithRawResponse,
    AsyncPointTasksResourceWithRawResponse,
    PointTasksResourceWithStreamingResponse,
    AsyncPointTasksResourceWithStreamingResponse,
)
from .user_points import (
    UserPointsResource,
    AsyncUserPointsResource,
    UserPointsResourceWithRawResponse,
    AsyncUserPointsResourceWithRawResponse,
    UserPointsResourceWithStreamingResponse,
    AsyncUserPointsResourceWithStreamingResponse,
)
from .aidoc_exotic import (
    AidocExoticResource,
    AsyncAidocExoticResource,
    AidocExoticResourceWithRawResponse,
    AsyncAidocExoticResourceWithRawResponse,
    AidocExoticResourceWithStreamingResponse,
    AsyncAidocExoticResourceWithStreamingResponse,
)
from .buriedpoints import (
    BuriedpointsResource,
    AsyncBuriedpointsResource,
    BuriedpointsResourceWithRawResponse,
    AsyncBuriedpointsResourceWithRawResponse,
    BuriedpointsResourceWithStreamingResponse,
    AsyncBuriedpointsResourceWithStreamingResponse,
)
from .check_points import (
    CheckPointsResource,
    AsyncCheckPointsResource,
    CheckPointsResourceWithRawResponse,
    AsyncCheckPointsResourceWithRawResponse,
    CheckPointsResourceWithStreamingResponse,
    AsyncCheckPointsResourceWithStreamingResponse,
)
from .pet_profiles import (
    PetProfilesResource,
    AsyncPetProfilesResource,
    PetProfilesResourceWithRawResponse,
    AsyncPetProfilesResourceWithRawResponse,
    PetProfilesResourceWithStreamingResponse,
    AsyncPetProfilesResourceWithStreamingResponse,
)
from .point_prices import (
    PointPricesResource,
    AsyncPointPricesResource,
    PointPricesResourceWithRawResponse,
    AsyncPointPricesResourceWithRawResponse,
    PointPricesResourceWithStreamingResponse,
    AsyncPointPricesResourceWithStreamingResponse,
)
from .upload_image import (
    UploadImageResource,
    AsyncUploadImageResource,
    UploadImageResourceWithRawResponse,
    AsyncUploadImageResourceWithRawResponse,
    UploadImageResourceWithStreamingResponse,
    AsyncUploadImageResourceWithStreamingResponse,
)
from .user_advices import (
    UserAdvicesResource,
    AsyncUserAdvicesResource,
    UserAdvicesResourceWithRawResponse,
    AsyncUserAdvicesResourceWithRawResponse,
    UserAdvicesResourceWithStreamingResponse,
    AsyncUserAdvicesResourceWithStreamingResponse,
)
from .aipic_exotics import (
    AipicExoticsResource,
    AsyncAipicExoticsResource,
    AipicExoticsResourceWithRawResponse,
    AsyncAipicExoticsResourceWithRawResponse,
    AipicExoticsResourceWithStreamingResponse,
    AsyncAipicExoticsResourceWithStreamingResponse,
)
from .point_details import (
    PointDetailsResource,
    AsyncPointDetailsResource,
    PointDetailsResourceWithRawResponse,
    AsyncPointDetailsResourceWithRawResponse,
    PointDetailsResourceWithStreamingResponse,
    AsyncPointDetailsResourceWithStreamingResponse,
)
from .medical_records import (
    MedicalRecordsResource,
    AsyncMedicalRecordsResource,
    MedicalRecordsResourceWithRawResponse,
    AsyncMedicalRecordsResourceWithRawResponse,
    MedicalRecordsResourceWithStreamingResponse,
    AsyncMedicalRecordsResourceWithStreamingResponse,
)
from .session_records import (
    SessionRecordsResource,
    AsyncSessionRecordsResource,
    SessionRecordsResourceWithRawResponse,
    AsyncSessionRecordsResourceWithRawResponse,
    SessionRecordsResourceWithStreamingResponse,
    AsyncSessionRecordsResourceWithStreamingResponse,
)
from .upload_image_oss import (
    UploadImageOssResource,
    AsyncUploadImageOssResource,
    UploadImageOssResourceWithRawResponse,
    AsyncUploadImageOssResourceWithRawResponse,
    UploadImageOssResourceWithStreamingResponse,
    AsyncUploadImageOssResourceWithStreamingResponse,
)
from .user_module_usages import (
    UserModuleUsagesResource,
    AsyncUserModuleUsagesResource,
    UserModuleUsagesResourceWithRawResponse,
    AsyncUserModuleUsagesResourceWithRawResponse,
    UserModuleUsagesResourceWithStreamingResponse,
    AsyncUserModuleUsagesResourceWithStreamingResponse,
)
from .medication_analysis import (
    MedicationAnalysisResource,
    AsyncMedicationAnalysisResource,
    MedicationAnalysisResourceWithRawResponse,
    AsyncMedicationAnalysisResourceWithRawResponse,
    MedicationAnalysisResourceWithStreamingResponse,
    AsyncMedicationAnalysisResourceWithStreamingResponse,
)

__all__ = [
    "AidocResource",
    "AsyncAidocResource",
    "AidocResourceWithRawResponse",
    "AsyncAidocResourceWithRawResponse",
    "AidocResourceWithStreamingResponse",
    "AsyncAidocResourceWithStreamingResponse",
    "AidocExoticResource",
    "AsyncAidocExoticResource",
    "AidocExoticResourceWithRawResponse",
    "AsyncAidocExoticResourceWithRawResponse",
    "AidocExoticResourceWithStreamingResponse",
    "AsyncAidocExoticResourceWithStreamingResponse",
    "SessionRecordsResource",
    "AsyncSessionRecordsResource",
    "SessionRecordsResourceWithRawResponse",
    "AsyncSessionRecordsResourceWithRawResponse",
    "SessionRecordsResourceWithStreamingResponse",
    "AsyncSessionRecordsResourceWithStreamingResponse",
    "MedicalRecordsResource",
    "AsyncMedicalRecordsResource",
    "MedicalRecordsResourceWithRawResponse",
    "AsyncMedicalRecordsResourceWithRawResponse",
    "MedicalRecordsResourceWithStreamingResponse",
    "AsyncMedicalRecordsResourceWithStreamingResponse",
    "AICheckupResource",
    "AsyncAICheckupResource",
    "AICheckupResourceWithRawResponse",
    "AsyncAICheckupResourceWithRawResponse",
    "AICheckupResourceWithStreamingResponse",
    "AsyncAICheckupResourceWithStreamingResponse",
    "AIConvResource",
    "AsyncAIConvResource",
    "AIConvResourceWithRawResponse",
    "AsyncAIConvResourceWithRawResponse",
    "AIConvResourceWithStreamingResponse",
    "AsyncAIConvResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "UploadResource",
    "AsyncUploadResource",
    "UploadResourceWithRawResponse",
    "AsyncUploadResourceWithRawResponse",
    "UploadResourceWithStreamingResponse",
    "AsyncUploadResourceWithStreamingResponse",
    "UploadImageResource",
    "AsyncUploadImageResource",
    "UploadImageResourceWithRawResponse",
    "AsyncUploadImageResourceWithRawResponse",
    "UploadImageResourceWithStreamingResponse",
    "AsyncUploadImageResourceWithStreamingResponse",
    "UploadImageOssResource",
    "AsyncUploadImageOssResource",
    "UploadImageOssResourceWithRawResponse",
    "AsyncUploadImageOssResourceWithRawResponse",
    "UploadImageOssResourceWithStreamingResponse",
    "AsyncUploadImageOssResourceWithStreamingResponse",
    "PetProfilesResource",
    "AsyncPetProfilesResource",
    "PetProfilesResourceWithRawResponse",
    "AsyncPetProfilesResourceWithRawResponse",
    "PetProfilesResourceWithStreamingResponse",
    "AsyncPetProfilesResourceWithStreamingResponse",
    "AIMemesResource",
    "AsyncAIMemesResource",
    "AIMemesResourceWithRawResponse",
    "AsyncAIMemesResourceWithRawResponse",
    "AIMemesResourceWithStreamingResponse",
    "AsyncAIMemesResourceWithStreamingResponse",
    "MedicationAnalysisResource",
    "AsyncMedicationAnalysisResource",
    "MedicationAnalysisResourceWithRawResponse",
    "AsyncMedicationAnalysisResourceWithRawResponse",
    "MedicationAnalysisResourceWithStreamingResponse",
    "AsyncMedicationAnalysisResourceWithStreamingResponse",
    "AipicResource",
    "AsyncAipicResource",
    "AipicResourceWithRawResponse",
    "AsyncAipicResourceWithRawResponse",
    "AipicResourceWithStreamingResponse",
    "AsyncAipicResourceWithStreamingResponse",
    "AipicsResource",
    "AsyncAipicsResource",
    "AipicsResourceWithRawResponse",
    "AsyncAipicsResourceWithRawResponse",
    "AipicsResourceWithStreamingResponse",
    "AsyncAipicsResourceWithStreamingResponse",
    "AipicExoticsResource",
    "AsyncAipicExoticsResource",
    "AipicExoticsResourceWithRawResponse",
    "AsyncAipicExoticsResourceWithRawResponse",
    "AipicExoticsResourceWithStreamingResponse",
    "AsyncAipicExoticsResourceWithStreamingResponse",
    "AITrialsResource",
    "AsyncAITrialsResource",
    "AITrialsResourceWithRawResponse",
    "AsyncAITrialsResourceWithRawResponse",
    "AITrialsResourceWithStreamingResponse",
    "AsyncAITrialsResourceWithStreamingResponse",
    "AITrialResource",
    "AsyncAITrialResource",
    "AITrialResourceWithRawResponse",
    "AsyncAITrialResourceWithRawResponse",
    "AITrialResourceWithStreamingResponse",
    "AsyncAITrialResourceWithStreamingResponse",
    "PoliciesResource",
    "AsyncPoliciesResource",
    "PoliciesResourceWithRawResponse",
    "AsyncPoliciesResourceWithRawResponse",
    "PoliciesResourceWithStreamingResponse",
    "AsyncPoliciesResourceWithStreamingResponse",
    "MagnumKeysResource",
    "AsyncMagnumKeysResource",
    "MagnumKeysResourceWithRawResponse",
    "AsyncMagnumKeysResourceWithRawResponse",
    "MagnumKeysResourceWithStreamingResponse",
    "AsyncMagnumKeysResourceWithStreamingResponse",
    "BuriedpointsResource",
    "AsyncBuriedpointsResource",
    "BuriedpointsResourceWithRawResponse",
    "AsyncBuriedpointsResourceWithRawResponse",
    "BuriedpointsResourceWithStreamingResponse",
    "AsyncBuriedpointsResourceWithStreamingResponse",
    "WhitelistResource",
    "AsyncWhitelistResource",
    "WhitelistResourceWithRawResponse",
    "AsyncWhitelistResourceWithRawResponse",
    "WhitelistResourceWithStreamingResponse",
    "AsyncWhitelistResourceWithStreamingResponse",
    "PetsResource",
    "AsyncPetsResource",
    "PetsResourceWithRawResponse",
    "AsyncPetsResourceWithRawResponse",
    "PetsResourceWithStreamingResponse",
    "AsyncPetsResourceWithStreamingResponse",
    "UserModuleUsagesResource",
    "AsyncUserModuleUsagesResource",
    "UserModuleUsagesResourceWithRawResponse",
    "AsyncUserModuleUsagesResourceWithRawResponse",
    "UserModuleUsagesResourceWithStreamingResponse",
    "AsyncUserModuleUsagesResourceWithStreamingResponse",
    "LoginsResource",
    "AsyncLoginsResource",
    "LoginsResourceWithRawResponse",
    "AsyncLoginsResourceWithRawResponse",
    "LoginsResourceWithStreamingResponse",
    "AsyncLoginsResourceWithStreamingResponse",
    "UserPointsResource",
    "AsyncUserPointsResource",
    "UserPointsResourceWithRawResponse",
    "AsyncUserPointsResourceWithRawResponse",
    "UserPointsResourceWithStreamingResponse",
    "AsyncUserPointsResourceWithStreamingResponse",
    "PointPricesResource",
    "AsyncPointPricesResource",
    "PointPricesResourceWithRawResponse",
    "AsyncPointPricesResourceWithRawResponse",
    "PointPricesResourceWithStreamingResponse",
    "AsyncPointPricesResourceWithStreamingResponse",
    "PointDetailsResource",
    "AsyncPointDetailsResource",
    "PointDetailsResourceWithRawResponse",
    "AsyncPointDetailsResourceWithRawResponse",
    "PointDetailsResourceWithStreamingResponse",
    "AsyncPointDetailsResourceWithStreamingResponse",
    "PointTasksResource",
    "AsyncPointTasksResource",
    "PointTasksResourceWithRawResponse",
    "AsyncPointTasksResourceWithRawResponse",
    "PointTasksResourceWithStreamingResponse",
    "AsyncPointTasksResourceWithStreamingResponse",
    "CheckPointsResource",
    "AsyncCheckPointsResource",
    "CheckPointsResourceWithRawResponse",
    "AsyncCheckPointsResourceWithRawResponse",
    "CheckPointsResourceWithStreamingResponse",
    "AsyncCheckPointsResourceWithStreamingResponse",
    "UserAdvicesResource",
    "AsyncUserAdvicesResource",
    "UserAdvicesResourceWithRawResponse",
    "AsyncUserAdvicesResourceWithRawResponse",
    "UserAdvicesResourceWithStreamingResponse",
    "AsyncUserAdvicesResourceWithStreamingResponse",
    "EvaluationResource",
    "AsyncEvaluationResource",
    "EvaluationResourceWithRawResponse",
    "AsyncEvaluationResourceWithRawResponse",
    "EvaluationResourceWithStreamingResponse",
    "AsyncEvaluationResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.users import summary_create_params
from ..._base_client import make_request_options

__all__ = ["SummaryResource", "AsyncSummaryResource"]


class SummaryResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SummaryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return SummaryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SummaryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return SummaryResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        合作交流信息保存

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/summary",
            body=maybe_transform({"session_id": session_id}, summary_create_params.SummaryCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSummaryResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSummaryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSummaryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSummaryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncSummaryResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        合作交流信息保存

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/summary",
            body=await async_maybe_transform({"session_id": session_id}, summary_create_params.SummaryCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SummaryResourceWithRawResponse:
    def __init__(self, summary: SummaryResource) -> None:
        self._summary = summary

        self.create = to_raw_response_wrapper(
            summary.create,
        )


class AsyncSummaryResourceWithRawResponse:
    def __init__(self, summary: AsyncSummaryResource) -> None:
        self._summary = summary

        self.create = async_to_raw_response_wrapper(
            summary.create,
        )


class SummaryResourceWithStreamingResponse:
    def __init__(self, summary: SummaryResource) -> None:
        self._summary = summary

        self.create = to_streamed_response_wrapper(
            summary.create,
        )


class AsyncSummaryResourceWithStreamingResponse:
    def __init__(self, summary: AsyncSummaryResource) -> None:
        self._summary = summary

        self.create = async_to_streamed_response_wrapper(
            summary.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import login_sms_params, login_wechat_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.login_response import LoginResponse

__all__ = ["LoginsResource", "AsyncLoginsResource"]


class LoginsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LoginsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return LoginsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LoginsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return LoginsResourceWithStreamingResponse(self)

    def sms(
        self,
        *,
        code: str,
        phone: str,
        login_from: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LoginResponse:
        """
        短信登录

        Args:
          login_from: 1-微信小程序 2-安卓 APP 3-IOS APP

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/sms-login",
            body=maybe_transform(
                {
                    "code": code,
                    "phone": phone,
                    "login_from": login_from,
                },
                login_sms_params.LoginSMSParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LoginResponse,
        )

    def wechat(
        self,
        *,
        wechat_code: str,
        encrypted_data: str | NotGiven = NOT_GIVEN,
        iv: str | NotGiven = NOT_GIVEN,
        module_type: int | NotGiven = NOT_GIVEN,
        phone_number: str | NotGiven = NOT_GIVEN,
        spread_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Logs in the user by WeChat

        Args:
          wechat_code: 会话 id

          encrypted_data: 加密数据

          iv: 加密初始向量

          module_type: 模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图片识别

          phone_number: 手机号

          spread_id: 推广人 sid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/wechat-login",
            body=maybe_transform(
                {
                    "wechat_code": wechat_code,
                    "encrypted_data": encrypted_data,
                    "iv": iv,
                    "module_type": module_type,
                    "phone_number": phone_number,
                    "spread_id": spread_id,
                },
                login_wechat_params.LoginWechatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncLoginsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLoginsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLoginsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLoginsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncLoginsResourceWithStreamingResponse(self)

    async def sms(
        self,
        *,
        code: str,
        phone: str,
        login_from: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LoginResponse:
        """
        短信登录

        Args:
          login_from: 1-微信小程序 2-安卓 APP 3-IOS APP

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/sms-login",
            body=await async_maybe_transform(
                {
                    "code": code,
                    "phone": phone,
                    "login_from": login_from,
                },
                login_sms_params.LoginSMSParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LoginResponse,
        )

    async def wechat(
        self,
        *,
        wechat_code: str,
        encrypted_data: str | NotGiven = NOT_GIVEN,
        iv: str | NotGiven = NOT_GIVEN,
        module_type: int | NotGiven = NOT_GIVEN,
        phone_number: str | NotGiven = NOT_GIVEN,
        spread_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Logs in the user by WeChat

        Args:
          wechat_code: 会话 id

          encrypted_data: 加密数据

          iv: 加密初始向量

          module_type: 模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图片识别

          phone_number: 手机号

          spread_id: 推广人 sid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/wechat-login",
            body=await async_maybe_transform(
                {
                    "wechat_code": wechat_code,
                    "encrypted_data": encrypted_data,
                    "iv": iv,
                    "module_type": module_type,
                    "phone_number": phone_number,
                    "spread_id": spread_id,
                },
                login_wechat_params.LoginWechatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class LoginsResourceWithRawResponse:
    def __init__(self, logins: LoginsResource) -> None:
        self._logins = logins

        self.sms = to_raw_response_wrapper(
            logins.sms,
        )
        self.wechat = to_raw_response_wrapper(
            logins.wechat,
        )


class AsyncLoginsResourceWithRawResponse:
    def __init__(self, logins: AsyncLoginsResource) -> None:
        self._logins = logins

        self.sms = async_to_raw_response_wrapper(
            logins.sms,
        )
        self.wechat = async_to_raw_response_wrapper(
            logins.wechat,
        )


class LoginsResourceWithStreamingResponse:
    def __init__(self, logins: LoginsResource) -> None:
        self._logins = logins

        self.sms = to_streamed_response_wrapper(
            logins.sms,
        )
        self.wechat = to_streamed_response_wrapper(
            logins.wechat,
        )


class AsyncLoginsResourceWithStreamingResponse:
    def __init__(self, logins: AsyncLoginsResource) -> None:
        self._logins = logins

        self.sms = async_to_streamed_response_wrapper(
            logins.sms,
        )
        self.wechat = async_to_streamed_response_wrapper(
            logins.wechat,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import user_point_cost_report_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.user_point_retrieve_response import UserPointRetrieveResponse

__all__ = ["UserPointsResource", "AsyncUserPointsResource"]


class UserPointsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UserPointsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return UserPointsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserPointsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return UserPointsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserPointRetrieveResponse:
        """获取用户积分"""
        return self._get(
            "/user-point",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserPointRetrieveResponse,
        )

    def cost_report(
        self,
        *,
        item_key: str | NotGiven = NOT_GIVEN,
        medical_record_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        积分消耗报表

        Args:
          medical_record_id: 病历 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/user-point/cost-report",
            body=maybe_transform(
                {
                    "item_key": item_key,
                    "medical_record_id": medical_record_id,
                },
                user_point_cost_report_params.UserPointCostReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUserPointsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUserPointsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserPointsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserPointsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncUserPointsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserPointRetrieveResponse:
        """获取用户积分"""
        return await self._get(
            "/user-point",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserPointRetrieveResponse,
        )

    async def cost_report(
        self,
        *,
        item_key: str | NotGiven = NOT_GIVEN,
        medical_record_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        积分消耗报表

        Args:
          medical_record_id: 病历 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/user-point/cost-report",
            body=await async_maybe_transform(
                {
                    "item_key": item_key,
                    "medical_record_id": medical_record_id,
                },
                user_point_cost_report_params.UserPointCostReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UserPointsResourceWithRawResponse:
    def __init__(self, user_points: UserPointsResource) -> None:
        self._user_points = user_points

        self.retrieve = to_raw_response_wrapper(
            user_points.retrieve,
        )
        self.cost_report = to_raw_response_wrapper(
            user_points.cost_report,
        )


class AsyncUserPointsResourceWithRawResponse:
    def __init__(self, user_points: AsyncUserPointsResource) -> None:
        self._user_points = user_points

        self.retrieve = async_to_raw_response_wrapper(
            user_points.retrieve,
        )
        self.cost_report = async_to_raw_response_wrapper(
            user_points.cost_report,
        )


class UserPointsResourceWithStreamingResponse:
    def __init__(self, user_points: UserPointsResource) -> None:
        self._user_points = user_points

        self.retrieve = to_streamed_response_wrapper(
            user_points.retrieve,
        )
        self.cost_report = to_streamed_response_wrapper(
            user_points.cost_report,
        )


class AsyncUserPointsResourceWithStreamingResponse:
    def __init__(self, user_points: AsyncUserPointsResource) -> None:
        self._user_points = user_points

        self.retrieve = async_to_streamed_response_wrapper(
            user_points.retrieve,
        )
        self.cost_report = async_to_streamed_response_wrapper(
            user_points.cost_report,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.users import contact_create_params
from ..._base_client import make_request_options

__all__ = ["ContactResource", "AsyncContactResource"]


class ContactResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ContactResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return ContactResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ContactResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return ContactResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        company_name: str | NotGiven = NOT_GIVEN,
        contact_name: str | NotGiven = NOT_GIVEN,
        mobile: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        合作交流信息保存

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/contact",
            body=maybe_transform(
                {
                    "company_name": company_name,
                    "contact_name": contact_name,
                    "mobile": mobile,
                },
                contact_create_params.ContactCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncContactResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncContactResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncContactResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncContactResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncContactResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        company_name: str | NotGiven = NOT_GIVEN,
        contact_name: str | NotGiven = NOT_GIVEN,
        mobile: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        合作交流信息保存

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/contact",
            body=await async_maybe_transform(
                {
                    "company_name": company_name,
                    "contact_name": contact_name,
                    "mobile": mobile,
                },
                contact_create_params.ContactCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class ContactResourceWithRawResponse:
    def __init__(self, contact: ContactResource) -> None:
        self._contact = contact

        self.create = to_raw_response_wrapper(
            contact.create,
        )


class AsyncContactResourceWithRawResponse:
    def __init__(self, contact: AsyncContactResource) -> None:
        self._contact = contact

        self.create = async_to_raw_response_wrapper(
            contact.create,
        )


class ContactResourceWithStreamingResponse:
    def __init__(self, contact: ContactResource) -> None:
        self._contact = contact

        self.create = to_streamed_response_wrapper(
            contact.create,
        )


class AsyncContactResourceWithStreamingResponse:
    def __init__(self, contact: AsyncContactResource) -> None:
        self._contact = contact

        self.create = async_to_streamed_response_wrapper(
            contact.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["PointTaskListResponse", "Data"]


class Data(BaseModel):
    id: Optional[int] = None
    """id"""

    achieve_count: Optional[int] = None
    """可完成次数"""

    bonus_point: Optional[str] = None
    """积分奖励"""

    condition_count: Optional[int] = None
    """完成条件次数"""

    description: Optional[str] = None
    """任务说明"""

    icon: Optional[str] = None
    """任务图标"""

    is_open: Optional[int] = None
    """0-未开启 1-开启"""

    related_module: Optional[str] = None
    """关联模块"""

    status: Optional[int] = None
    """1-未完成 2-未领取"""

    task_action: Optional[str] = None
    """任务动作"""

    task_name: Optional[str] = None
    """任务名称"""

    to_page: Optional[str] = None
    """跳转页面"""


class PointTaskListResponse(BaseModel):
    data: Optional[List[Data]] = None

    message: Optional[str] = None
    """message"""

    success: Optional[bool] = None
    """success"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UserChatVParams"]


class UserChatVParams(TypedDict, total=False):
    content: str

    session_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

__all__ = ["MedicalRecordCreateListParams"]


class MedicalRecordCreateListParams(TypedDict, total=False):
    limit: int
    """每页数量"""

    module_type: Iterable[int]

    page: int
    """页码"""

    pet_profile_id: Iterable[int]
    """宠物档案 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUsers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_chat_v(self, client: Czlai) -> None:
        user = client.users.chat_v()
        assert user is None

    @parametrize
    def test_method_chat_v_with_all_params(self, client: Czlai) -> None:
        user = client.users.chat_v(
            content="content",
            session_id="session_id",
        )
        assert user is None

    @parametrize
    def test_raw_response_chat_v(self, client: Czlai) -> None:
        response = client.users.with_raw_response.chat_v()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = response.parse()
        assert user is None

    @parametrize
    def test_streaming_response_chat_v(self, client: Czlai) -> None:
        with client.users.with_streaming_response.chat_v() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_logout(self, client: Czlai) -> None:
        user = client.users.logout()
        assert user is None

    @parametrize
    def test_raw_response_logout(self, client: Czlai) -> None:
        response = client.users.with_raw_response.logout()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = response.parse()
        assert user is None

    @parametrize
    def test_streaming_response_logout(self, client: Czlai) -> None:
        with client.users.with_streaming_response.logout() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_send_sms(self, client: Czlai) -> None:
        user = client.users.send_sms()
        assert user is None

    @parametrize
    def test_method_send_sms_with_all_params(self, client: Czlai) -> None:
        user = client.users.send_sms(
            phone="phone",
        )
        assert user is None

    @parametrize
    def test_raw_response_send_sms(self, client: Czlai) -> None:
        response = client.users.with_raw_response.send_sms()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = response.parse()
        assert user is None

    @parametrize
    def test_streaming_response_send_sms(self, client: Czlai) -> None:
        with client.users.with_streaming_response.send_sms() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True


class TestAsyncUsers:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_chat_v(self, async_client: AsyncCzlai) -> None:
        user = await async_client.users.chat_v()
        assert user is None

    @parametrize
    async def test_method_chat_v_with_all_params(self, async_client: AsyncCzlai) -> None:
        user = await async_client.users.chat_v(
            content="content",
            session_id="session_id",
        )
        assert user is None

    @parametrize
    async def test_raw_response_chat_v(self, async_client: AsyncCzlai) -> None:
        response = await async_client.users.with_raw_response.chat_v()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = await response.parse()
        assert user is None

    @parametrize
    async def test_streaming_response_chat_v(self, async_client: AsyncCzlai) -> None:
        async with async_client.users.with_streaming_response.chat_v() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = await response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_logout(self, async_client: AsyncCzlai) -> None:
        user = await async_client.users.logout()
        assert user is None

    @parametrize
    async def test_raw_response_logout(self, async_client: AsyncCzlai) -> None:
        response = await async_client.users.with_raw_response.logout()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = await response.parse()
        assert user is None

    @parametrize
    async def test_streaming_response_logout(self, async_client: AsyncCzlai) -> None:
        async with async_client.users.with_streaming_response.logout() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = await response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_send_sms(self, async_client: AsyncCzlai) -> None:
        user = await async_client.users.send_sms()
        assert user is None

    @parametrize
    async def test_method_send_sms_with_all_params(self, async_client: AsyncCzlai) -> None:
        user = await async_client.users.send_sms(
            phone="phone",
        )
        assert user is None

    @parametrize
    async def test_raw_response_send_sms(self, async_client: AsyncCzlai) -> None:
        response = await async_client.users.with_raw_response.send_sms()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user = await response.parse()
        assert user is None

    @parametrize
    async def test_streaming_response_send_sms(self, async_client: AsyncCzlai) -> None:
        async with async_client.users.with_streaming_response.send_sms() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user = await response.parse()
            assert user is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAITrial:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_answer(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.answer()
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_answer_with_all_params(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.answer(
            service_type=0,
            session_id="session_id",
            user_input="user_input",
        )
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_answer(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.answer()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_answer(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.answer() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert_matches_type(str, ai_trial, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_history(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.history(
            content="content",
            role="role",
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    def test_method_history_with_all_params(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.history(
            content="content",
            role="role",
            session_id="session_id",
            content_type=0,
            module_type=0,
            stage=0,
        )
        assert ai_trial is None

    @parametrize
    def test_raw_response_history(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.history(
            content="content",
            role="role",
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert ai_trial is None

    @parametrize
    def test_streaming_response_history(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.history(
            content="content",
            role="role",
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_relation(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.relation()
        assert ai_trial is None

    @parametrize
    def test_method_relation_with_all_params(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.relation(
            service_type=1,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    def test_raw_response_relation(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.relation()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert ai_trial is None

    @parametrize
    def test_streaming_response_relation(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.relation() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.report(
            service_type=0,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.report(
            service_type=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert ai_trial is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.report(
            service_type=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_session_start(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.session_start()
        assert ai_trial is None

    @parametrize
    def test_method_session_start_with_all_params(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.session_start(
            content="content",
            service_type=0,
        )
        assert ai_trial is None

    @parametrize
    def test_raw_response_session_start(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.session_start()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert ai_trial is None

    @parametrize
    def test_streaming_response_session_start(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.session_start() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_summary(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.summary()
        assert ai_trial is None

    @parametrize
    def test_method_summary_with_all_params(self, client: Czlai) -> None:
        ai_trial = client.ai_trial.summary(
            service_type=0,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    def test_raw_response_summary(self, client: Czlai) -> None:
        response = client.ai_trial.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = response.parse()
        assert ai_trial is None

    @parametrize
    def test_streaming_response_summary(self, client: Czlai) -> None:
        with client.ai_trial.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAITrial:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_answer(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.answer()
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_answer_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.answer(
            service_type=0,
            session_id="session_id",
            user_input="user_input",
        )
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_answer(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.answer()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert_matches_type(str, ai_trial, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_answer(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.answer() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert_matches_type(str, ai_trial, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_history(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.history(
            content="content",
            role="role",
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    async def test_method_history_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.history(
            content="content",
            role="role",
            session_id="session_id",
            content_type=0,
            module_type=0,
            stage=0,
        )
        assert ai_trial is None

    @parametrize
    async def test_raw_response_history(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.history(
            content="content",
            role="role",
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert ai_trial is None

    @parametrize
    async def test_streaming_response_history(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.history(
            content="content",
            role="role",
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_relation(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.relation()
        assert ai_trial is None

    @parametrize
    async def test_method_relation_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.relation(
            service_type=1,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    async def test_raw_response_relation(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.relation()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert ai_trial is None

    @parametrize
    async def test_streaming_response_relation(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.relation() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.report(
            service_type=0,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.report(
            service_type=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert ai_trial is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.report(
            service_type=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_session_start(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.session_start()
        assert ai_trial is None

    @parametrize
    async def test_method_session_start_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.session_start(
            content="content",
            service_type=0,
        )
        assert ai_trial is None

    @parametrize
    async def test_raw_response_session_start(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.session_start()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert ai_trial is None

    @parametrize
    async def test_streaming_response_session_start(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.session_start() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_summary(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.summary()
        assert ai_trial is None

    @parametrize
    async def test_method_summary_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_trial = await async_client.ai_trial.summary(
            service_type=0,
            session_id="session_id",
        )
        assert ai_trial is None

    @parametrize
    async def test_raw_response_summary(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_trial.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_trial = await response.parse()
        assert ai_trial is None

    @parametrize
    async def test_streaming_response_summary(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_trial.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_trial = await response.parse()
            assert ai_trial is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LoginWechatParams"]


class LoginWechatParams(TypedDict, total=False):
    wechat_code: Required[str]
    """会话 id"""

    encrypted_data: Annotated[str, PropertyInfo(alias="encryptedData")]
    """加密数据"""

    iv: str
    """加密初始向量"""

    module_type: int
    """模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图片识别"""

    phone_number: str
    """手机号"""

    spread_id: int
    """推广人 sid"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import (
    pet_profile_create_params,
    pet_profile_delete_params,
    pet_profile_update_params,
    pet_profile_ex_info_params,
    pet_profile_variety_params,
    pet_profile_retrieve_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.pet_profile_list_response import PetProfileListResponse
from ..types.pet_profile_delete_response import PetProfileDeleteResponse
from ..types.pet_profile_retrieve_response import PetProfileRetrieveResponse

__all__ = ["PetProfilesResource", "AsyncPetProfilesResource"]


class PetProfilesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PetProfilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return PetProfilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PetProfilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return PetProfilesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        allergy_history: Optional[str] | NotGiven = NOT_GIVEN,
        avatar: Optional[str] | NotGiven = NOT_GIVEN,
        birthday: str | NotGiven = NOT_GIVEN,
        disease_history: Optional[str] | NotGiven = NOT_GIVEN,
        family_history: Optional[str] | NotGiven = NOT_GIVEN,
        gender: int | NotGiven = NOT_GIVEN,
        is_neutered: Optional[int] | NotGiven = NOT_GIVEN,
        is_vaccination: int | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        pet_type: int | NotGiven = NOT_GIVEN,
        pet_variety: Optional[str] | NotGiven = NOT_GIVEN,
        vaccination_date: Optional[str] | NotGiven = NOT_GIVEN,
        weight: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        创建宠物档案

        Args:
          allergy_history: 过敏史

          avatar: 头像

          birthday: 生日

          disease_history: 疾病史

          family_history: 家族史

          gender: 性别 1-公 2-母

          is_neutered: 是否已绝育 0-否 1-是

          is_vaccination: 是否已接种疫苗 0-否 1-是

          name: 宠物名字

          pet_type: 宠物类型

          pet_variety: 宠物品种

          vaccination_date: 疫苗时间

          weight: 重量

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/pet-profile",
            body=maybe_transform(
                {
                    "allergy_history": allergy_history,
                    "avatar": avatar,
                    "birthday": birthday,
                    "disease_history": disease_history,
                    "family_history": family_history,
                    "gender": gender,
                    "is_neutered": is_neutered,
                    "is_vaccination": is_vaccination,
                    "name": name,
                    "pet_type": pet_type,
                    "pet_variety": pet_variety,
                    "vaccination_date": vaccination_date,
                    "weight": weight,
                },
                pet_profile_create_params.PetProfileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileRetrieveResponse:
        """
        获取宠物档案

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/pet-profile",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_retrieve_params.PetProfileRetrieveParams
                ),
            ),
            cast_to=PetProfileRetrieveResponse,
        )

    def update(
        self,
        *,
        pet_profile_id: int,
        allergy_history: Optional[str] | NotGiven = NOT_GIVEN,
        avatar: Optional[str] | NotGiven = NOT_GIVEN,
        birthday: str | NotGiven = NOT_GIVEN,
        disease_history: Optional[str] | NotGiven = NOT_GIVEN,
        family_history: Optional[str] | NotGiven = NOT_GIVEN,
        gender: int | NotGiven = NOT_GIVEN,
        is_neutered: Optional[int] | NotGiven = NOT_GIVEN,
        is_vaccination: int | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        pet_type: int | NotGiven = NOT_GIVEN,
        pet_variety: Optional[str] | NotGiven = NOT_GIVEN,
        vaccination_date: Optional[str] | NotGiven = NOT_GIVEN,
        weight: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        更新宠物档案

        Args:
          allergy_history: 过敏史

          avatar: 头像

          birthday: 生日

          disease_history: 疾病史

          family_history: 家族史

          gender: 性别 1-公 2-母

          is_neutered: 是否已绝育 0-否 1-是

          is_vaccination: 是否已接种疫苗 0-否 1-是

          name: 宠物名字

          pet_type: 宠物类型

          pet_variety: 宠物品种

          vaccination_date: 疫苗时间

          weight: 重量

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            "/pet-profile",
            body=maybe_transform(
                {
                    "allergy_history": allergy_history,
                    "avatar": avatar,
                    "birthday": birthday,
                    "disease_history": disease_history,
                    "family_history": family_history,
                    "gender": gender,
                    "is_neutered": is_neutered,
                    "is_vaccination": is_vaccination,
                    "name": name,
                    "pet_type": pet_type,
                    "pet_variety": pet_variety,
                    "vaccination_date": vaccination_date,
                    "weight": weight,
                },
                pet_profile_update_params.PetProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_update_params.PetProfileUpdateParams
                ),
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileListResponse:
        """获取宠物档案列表"""
        return self._get(
            "/pet-profiles",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PetProfileListResponse,
        )

    def delete(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileDeleteResponse:
        """
        删除宠物档案

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/pet-profile",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_delete_params.PetProfileDeleteParams
                ),
            ),
            cast_to=PetProfileDeleteResponse,
        )

    def ex_info(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取宠物档案扩展信息

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/pet-profile/ex-info",
            body=maybe_transform({"pet_profile_id": pet_profile_id}, pet_profile_ex_info_params.PetProfileExInfoParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def variety(
        self,
        *,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        获取宠物品种

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/pet-profile/variety",
            body=maybe_transform({"user_input": user_input}, pet_profile_variety_params.PetProfileVarietyParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncPetProfilesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPetProfilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPetProfilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPetProfilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncPetProfilesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        allergy_history: Optional[str] | NotGiven = NOT_GIVEN,
        avatar: Optional[str] | NotGiven = NOT_GIVEN,
        birthday: str | NotGiven = NOT_GIVEN,
        disease_history: Optional[str] | NotGiven = NOT_GIVEN,
        family_history: Optional[str] | NotGiven = NOT_GIVEN,
        gender: int | NotGiven = NOT_GIVEN,
        is_neutered: Optional[int] | NotGiven = NOT_GIVEN,
        is_vaccination: int | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        pet_type: int | NotGiven = NOT_GIVEN,
        pet_variety: Optional[str] | NotGiven = NOT_GIVEN,
        vaccination_date: Optional[str] | NotGiven = NOT_GIVEN,
        weight: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        创建宠物档案

        Args:
          allergy_history: 过敏史

          avatar: 头像

          birthday: 生日

          disease_history: 疾病史

          family_history: 家族史

          gender: 性别 1-公 2-母

          is_neutered: 是否已绝育 0-否 1-是

          is_vaccination: 是否已接种疫苗 0-否 1-是

          name: 宠物名字

          pet_type: 宠物类型

          pet_variety: 宠物品种

          vaccination_date: 疫苗时间

          weight: 重量

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/pet-profile",
            body=await async_maybe_transform(
                {
                    "allergy_history": allergy_history,
                    "avatar": avatar,
                    "birthday": birthday,
                    "disease_history": disease_history,
                    "family_history": family_history,
                    "gender": gender,
                    "is_neutered": is_neutered,
                    "is_vaccination": is_vaccination,
                    "name": name,
                    "pet_type": pet_type,
                    "pet_variety": pet_variety,
                    "vaccination_date": vaccination_date,
                    "weight": weight,
                },
                pet_profile_create_params.PetProfileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileRetrieveResponse:
        """
        获取宠物档案

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/pet-profile",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_retrieve_params.PetProfileRetrieveParams
                ),
            ),
            cast_to=PetProfileRetrieveResponse,
        )

    async def update(
        self,
        *,
        pet_profile_id: int,
        allergy_history: Optional[str] | NotGiven = NOT_GIVEN,
        avatar: Optional[str] | NotGiven = NOT_GIVEN,
        birthday: str | NotGiven = NOT_GIVEN,
        disease_history: Optional[str] | NotGiven = NOT_GIVEN,
        family_history: Optional[str] | NotGiven = NOT_GIVEN,
        gender: int | NotGiven = NOT_GIVEN,
        is_neutered: Optional[int] | NotGiven = NOT_GIVEN,
        is_vaccination: int | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        pet_type: int | NotGiven = NOT_GIVEN,
        pet_variety: Optional[str] | NotGiven = NOT_GIVEN,
        vaccination_date: Optional[str] | NotGiven = NOT_GIVEN,
        weight: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        更新宠物档案

        Args:
          allergy_history: 过敏史

          avatar: 头像

          birthday: 生日

          disease_history: 疾病史

          family_history: 家族史

          gender: 性别 1-公 2-母

          is_neutered: 是否已绝育 0-否 1-是

          is_vaccination: 是否已接种疫苗 0-否 1-是

          name: 宠物名字

          pet_type: 宠物类型

          pet_variety: 宠物品种

          vaccination_date: 疫苗时间

          weight: 重量

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            "/pet-profile",
            body=await async_maybe_transform(
                {
                    "allergy_history": allergy_history,
                    "avatar": avatar,
                    "birthday": birthday,
                    "disease_history": disease_history,
                    "family_history": family_history,
                    "gender": gender,
                    "is_neutered": is_neutered,
                    "is_vaccination": is_vaccination,
                    "name": name,
                    "pet_type": pet_type,
                    "pet_variety": pet_variety,
                    "vaccination_date": vaccination_date,
                    "weight": weight,
                },
                pet_profile_update_params.PetProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_update_params.PetProfileUpdateParams
                ),
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileListResponse:
        """获取宠物档案列表"""
        return await self._get(
            "/pet-profiles",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PetProfileListResponse,
        )

    async def delete(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PetProfileDeleteResponse:
        """
        删除宠物档案

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/pet-profile",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"pet_profile_id": pet_profile_id}, pet_profile_delete_params.PetProfileDeleteParams
                ),
            ),
            cast_to=PetProfileDeleteResponse,
        )

    async def ex_info(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取宠物档案扩展信息

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/pet-profile/ex-info",
            body=await async_maybe_transform(
                {"pet_profile_id": pet_profile_id}, pet_profile_ex_info_params.PetProfileExInfoParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def variety(
        self,
        *,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        获取宠物品种

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/pet-profile/variety",
            body=await async_maybe_transform(
                {"user_input": user_input}, pet_profile_variety_params.PetProfileVarietyParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class PetProfilesResourceWithRawResponse:
    def __init__(self, pet_profiles: PetProfilesResource) -> None:
        self._pet_profiles = pet_profiles

        self.create = to_raw_response_wrapper(
            pet_profiles.create,
        )
        self.retrieve = to_raw_response_wrapper(
            pet_profiles.retrieve,
        )
        self.update = to_raw_response_wrapper(
            pet_profiles.update,
        )
        self.list = to_raw_response_wrapper(
            pet_profiles.list,
        )
        self.delete = to_raw_response_wrapper(
            pet_profiles.delete,
        )
        self.ex_info = to_raw_response_wrapper(
            pet_profiles.ex_info,
        )
        self.variety = to_raw_response_wrapper(
            pet_profiles.variety,
        )


class AsyncPetProfilesResourceWithRawResponse:
    def __init__(self, pet_profiles: AsyncPetProfilesResource) -> None:
        self._pet_profiles = pet_profiles

        self.create = async_to_raw_response_wrapper(
            pet_profiles.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            pet_profiles.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            pet_profiles.update,
        )
        self.list = async_to_raw_response_wrapper(
            pet_profiles.list,
        )
        self.delete = async_to_raw_response_wrapper(
            pet_profiles.delete,
        )
        self.ex_info = async_to_raw_response_wrapper(
            pet_profiles.ex_info,
        )
        self.variety = async_to_raw_response_wrapper(
            pet_profiles.variety,
        )


class PetProfilesResourceWithStreamingResponse:
    def __init__(self, pet_profiles: PetProfilesResource) -> None:
        self._pet_profiles = pet_profiles

        self.create = to_streamed_response_wrapper(
            pet_profiles.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            pet_profiles.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            pet_profiles.update,
        )
        self.list = to_streamed_response_wrapper(
            pet_profiles.list,
        )
        self.delete = to_streamed_response_wrapper(
            pet_profiles.delete,
        )
        self.ex_info = to_streamed_response_wrapper(
            pet_profiles.ex_info,
        )
        self.variety = to_streamed_response_wrapper(
            pet_profiles.variety,
        )


class AsyncPetProfilesResourceWithStreamingResponse:
    def __init__(self, pet_profiles: AsyncPetProfilesResource) -> None:
        self._pet_profiles = pet_profiles

        self.create = async_to_streamed_response_wrapper(
            pet_profiles.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            pet_profiles.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            pet_profiles.update,
        )
        self.list = async_to_streamed_response_wrapper(
            pet_profiles.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            pet_profiles.delete,
        )
        self.ex_info = async_to_streamed_response_wrapper(
            pet_profiles.ex_info,
        )
        self.variety = async_to_streamed_response_wrapper(
            pet_profiles.variety,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ContactCreateParams"]


class ContactCreateParams(TypedDict, total=False):
    company_name: str

    contact_name: str

    mobile: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    MedicalRecordRetrieveResponse,
    MedicalRecordCreateListResponse,
)
from tests.utils import assert_matches_type
from czlai._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMedicalRecords:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: Czlai) -> None:
        medical_record = client.medical_records.retrieve(
            report_id=0,
        )
        assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Czlai) -> None:
        response = client.medical_records.with_raw_response.retrieve(
            report_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = response.parse()
        assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Czlai) -> None:
        with client.medical_records.with_streaming_response.retrieve(
            report_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = response.parse()
            assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update(self, client: Czlai) -> None:
        medical_record = client.medical_records.update()
        assert medical_record is None

    @parametrize
    def test_method_update_with_all_params(self, client: Czlai) -> None:
        medical_record = client.medical_records.update(
            is_read=0,
            report_id=0,
            report_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            stage="stage",
            status=0,
        )
        assert medical_record is None

    @parametrize
    def test_raw_response_update(self, client: Czlai) -> None:
        response = client.medical_records.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = response.parse()
        assert medical_record is None

    @parametrize
    def test_streaming_response_update(self, client: Czlai) -> None:
        with client.medical_records.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = response.parse()
            assert medical_record is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_list(self, client: Czlai) -> None:
        medical_record = client.medical_records.create_list()
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    def test_method_create_list_with_all_params(self, client: Czlai) -> None:
        medical_record = client.medical_records.create_list(
            limit=0,
            module_type=[0, 0, 0],
            page=0,
            pet_profile_id=[0, 0, 0],
        )
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    def test_raw_response_create_list(self, client: Czlai) -> None:
        response = client.medical_records.with_raw_response.create_list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = response.parse()
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    def test_streaming_response_create_list(self, client: Czlai) -> None:
        with client.medical_records.with_streaming_response.create_list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = response.parse()
            assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_ongoing_record(self, client: Czlai) -> None:
        medical_record = client.medical_records.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        )
        assert medical_record is None

    @parametrize
    def test_raw_response_ongoing_record(self, client: Czlai) -> None:
        response = client.medical_records.with_raw_response.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = response.parse()
        assert medical_record is None

    @parametrize
    def test_streaming_response_ongoing_record(self, client: Czlai) -> None:
        with client.medical_records.with_streaming_response.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = response.parse()
            assert medical_record is None

        assert cast(Any, response.is_closed) is True


class TestAsyncMedicalRecords:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.retrieve(
            report_id=0,
        )
        assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medical_records.with_raw_response.retrieve(
            report_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = await response.parse()
        assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCzlai) -> None:
        async with async_client.medical_records.with_streaming_response.retrieve(
            report_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = await response.parse()
            assert_matches_type(MedicalRecordRetrieveResponse, medical_record, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.update()
        assert medical_record is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.update(
            is_read=0,
            report_id=0,
            report_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            stage="stage",
            status=0,
        )
        assert medical_record is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medical_records.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = await response.parse()
        assert medical_record is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCzlai) -> None:
        async with async_client.medical_records.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = await response.parse()
            assert medical_record is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_list(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.create_list()
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    async def test_method_create_list_with_all_params(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.create_list(
            limit=0,
            module_type=[0, 0, 0],
            page=0,
            pet_profile_id=[0, 0, 0],
        )
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    async def test_raw_response_create_list(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medical_records.with_raw_response.create_list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = await response.parse()
        assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

    @parametrize
    async def test_streaming_response_create_list(self, async_client: AsyncCzlai) -> None:
        async with async_client.medical_records.with_streaming_response.create_list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = await response.parse()
            assert_matches_type(MedicalRecordCreateListResponse, medical_record, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_ongoing_record(self, async_client: AsyncCzlai) -> None:
        medical_record = await async_client.medical_records.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        )
        assert medical_record is None

    @parametrize
    async def test_raw_response_ongoing_record(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medical_records.with_raw_response.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medical_record = await response.parse()
        assert medical_record is None

    @parametrize
    async def test_streaming_response_ongoing_record(self, async_client: AsyncCzlai) -> None:
        async with async_client.medical_records.with_streaming_response.ongoing_record(
            module_type=0,
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medical_record = await response.parse()
            assert medical_record is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...types import user_module_usage_get_add_wecome_bonus_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .is_add_wecome import (
    IsAddWecomeResource,
    AsyncIsAddWecomeResource,
    IsAddWecomeResourceWithRawResponse,
    AsyncIsAddWecomeResourceWithRawResponse,
    IsAddWecomeResourceWithStreamingResponse,
    AsyncIsAddWecomeResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from ...types.user_module_usage_get_add_wecome_bonus_response import UserModuleUsageGetAddWecomeBonusResponse
from ...types.user_module_usage_get_wechat_mini_qrcode_response import UserModuleUsageGetWechatMiniQrcodeResponse

__all__ = ["UserModuleUsagesResource", "AsyncUserModuleUsagesResource"]


class UserModuleUsagesResource(SyncAPIResource):
    @cached_property
    def is_add_wecome(self) -> IsAddWecomeResource:
        return IsAddWecomeResource(self._client)

    @cached_property
    def with_raw_response(self) -> UserModuleUsagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return UserModuleUsagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserModuleUsagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return UserModuleUsagesResourceWithStreamingResponse(self)

    def checkin(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """签到"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/user-module-usage/checkin",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_add_wecome_bonus(
        self,
        *,
        module_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserModuleUsageGetAddWecomeBonusResponse:
        """
        领取添加企微的奖励

        Args:
          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/user-module-usage/get-add-wecome-bonus",
            body=maybe_transform(
                {"module_type": module_type},
                user_module_usage_get_add_wecome_bonus_params.UserModuleUsageGetAddWecomeBonusParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserModuleUsageGetAddWecomeBonusResponse,
        )

    def get_wechat_mini_qrcode(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserModuleUsageGetWechatMiniQrcodeResponse:
        """获取微信小程序二维码"""
        return self._post(
            "/user-module-usage/get-wechat-mini-qrcode",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserModuleUsageGetWechatMiniQrcodeResponse,
        )


class AsyncUserModuleUsagesResource(AsyncAPIResource):
    @cached_property
    def is_add_wecome(self) -> AsyncIsAddWecomeResource:
        return AsyncIsAddWecomeResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncUserModuleUsagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserModuleUsagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserModuleUsagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncUserModuleUsagesResourceWithStreamingResponse(self)

    async def checkin(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """签到"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/user-module-usage/checkin",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_add_wecome_bonus(
        self,
        *,
        module_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserModuleUsageGetAddWecomeBonusResponse:
        """
        领取添加企微的奖励

        Args:
          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/user-module-usage/get-add-wecome-bonus",
            body=await async_maybe_transform(
                {"module_type": module_type},
                user_module_usage_get_add_wecome_bonus_params.UserModuleUsageGetAddWecomeBonusParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserModuleUsageGetAddWecomeBonusResponse,
        )

    async def get_wechat_mini_qrcode(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UserModuleUsageGetWechatMiniQrcodeResponse:
        """获取微信小程序二维码"""
        return await self._post(
            "/user-module-usage/get-wechat-mini-qrcode",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserModuleUsageGetWechatMiniQrcodeResponse,
        )


class UserModuleUsagesResourceWithRawResponse:
    def __init__(self, user_module_usages: UserModuleUsagesResource) -> None:
        self._user_module_usages = user_module_usages

        self.checkin = to_raw_response_wrapper(
            user_module_usages.checkin,
        )
        self.get_add_wecome_bonus = to_raw_response_wrapper(
            user_module_usages.get_add_wecome_bonus,
        )
        self.get_wechat_mini_qrcode = to_raw_response_wrapper(
            user_module_usages.get_wechat_mini_qrcode,
        )

    @cached_property
    def is_add_wecome(self) -> IsAddWecomeResourceWithRawResponse:
        return IsAddWecomeResourceWithRawResponse(self._user_module_usages.is_add_wecome)


class AsyncUserModuleUsagesResourceWithRawResponse:
    def __init__(self, user_module_usages: AsyncUserModuleUsagesResource) -> None:
        self._user_module_usages = user_module_usages

        self.checkin = async_to_raw_response_wrapper(
            user_module_usages.checkin,
        )
        self.get_add_wecome_bonus = async_to_raw_response_wrapper(
            user_module_usages.get_add_wecome_bonus,
        )
        self.get_wechat_mini_qrcode = async_to_raw_response_wrapper(
            user_module_usages.get_wechat_mini_qrcode,
        )

    @cached_property
    def is_add_wecome(self) -> AsyncIsAddWecomeResourceWithRawResponse:
        return AsyncIsAddWecomeResourceWithRawResponse(self._user_module_usages.is_add_wecome)


class UserModuleUsagesResourceWithStreamingResponse:
    def __init__(self, user_module_usages: UserModuleUsagesResource) -> None:
        self._user_module_usages = user_module_usages

        self.checkin = to_streamed_response_wrapper(
            user_module_usages.checkin,
        )
        self.get_add_wecome_bonus = to_streamed_response_wrapper(
            user_module_usages.get_add_wecome_bonus,
        )
        self.get_wechat_mini_qrcode = to_streamed_response_wrapper(
            user_module_usages.get_wechat_mini_qrcode,
        )

    @cached_property
    def is_add_wecome(self) -> IsAddWecomeResourceWithStreamingResponse:
        return IsAddWecomeResourceWithStreamingResponse(self._user_module_usages.is_add_wecome)


class AsyncUserModuleUsagesResourceWithStreamingResponse:
    def __init__(self, user_module_usages: AsyncUserModuleUsagesResource) -> None:
        self._user_module_usages = user_module_usages

        self.checkin = async_to_streamed_response_wrapper(
            user_module_usages.checkin,
        )
        self.get_add_wecome_bonus = async_to_streamed_response_wrapper(
            user_module_usages.get_add_wecome_bonus,
        )
        self.get_wechat_mini_qrcode = async_to_streamed_response_wrapper(
            user_module_usages.get_wechat_mini_qrcode,
        )

    @cached_property
    def is_add_wecome(self) -> AsyncIsAddWecomeResourceWithStreamingResponse:
        return AsyncIsAddWecomeResourceWithStreamingResponse(self._user_module_usages.is_add_wecome)
